#
# BEGIN COPYRIGHT BLOCK
# Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
# Copyright (C) 2005 Red Hat, Inc.
# All rights reserved.
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation version
# 2.1 of the License.
#                                                                                  
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#                                                                                  
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
# END COPYRIGHT BLOCK
#
#
# This makefile is used to grab all the components needed to build.
#
#
#

COMMA :=,
NULLSTRING :=
SPACE :=$(NULLSTRING) # the space is between the ) and the #

ifeq ($(ARCH), WINNT)
EXE_SUFFIX = .exe
else # unix - windows has no lib name prefix, except for nspr
LIB_PREFIX = lib
endif

include $(ABS_ROOT)/nsperl.mk

ifeq ($(INTERNAL_BUILD), 1)
include $(ABS_ROOT)/internal_buildpaths.mk
else
include $(ABS_ROOT)/buildpaths.mk
endif

all:
 
#Temporary integration area components
INT_ICU = 0
INT_NSPR = 0
INT_NSS = 0
INT_LDAPSDK = 0
INT_SVRCORE = 0 

# NSPR20 Library
NSPR_LIBNAMES = plc4 plds4
ifeq ($(ARCH), SOLARIS)
  ifeq ($(NSPR_RELDATE), v4.2.2)
# no need after v4.4.1
NSPR_LIBNAMES += ultrasparc4 
# just need ultrasparc for now
LIBS_TO_PKG += $(addsuffix .$(DLL_SUFFIX),$(addprefix $(NSPR_LIBPATH)/lib,ultrasparc4))
  endif
endif
NSPR_LIBNAMES += nspr4
ifdef NSPR_INCLUDE_DIR
 NSPR_INCDIR = $(NSPR_INCLUDE_DIR)
else
 ifdef NSPR_SOURCE_ROOT
  NSPR_INCDIR = $(NSPR_SOURCE_ROOT)/dist/$(MOZ_OBJDIR_NAME)/include
 else
  NSPR_INCDIR = $(NSPR_BUILD_DIR)/include
 endif
endif
ifdef NSPR_LIB_DIR
 NSPR_LIBPATH = $(NSPR_LIB_DIR)
else
 ifdef NSPR_SOURCE_ROOT
  NSPR_LIBPATH = $(NSPR_SOURCE_ROOT)/dist/$(MOZ_OBJDIR_NAME)/lib
 else
  NSPR_LIBPATH = $(NSPR_BUILD_DIR)/lib
 endif
endif
NSPR_INCLUDE = -I$(NSPR_INCDIR)
NSPR_LIBS_TO_PKG = $(addsuffix .$(DLL_SUFFIX),$(addprefix $(NSPR_LIBPATH)/lib,$(NSPR_LIBNAMES)))

ifeq ($(ARCH), WINNT)
  NSPRDLL_NAME = $(addprefix lib, $(NSPR_LIBNAMES))
  NSPROBJNAME = $(addsuffix .lib, $(NSPRDLL_NAME))
  NSPRLINK = /LIBPATH:$(NSPR_LIBPATH) $(NSPROBJNAME)
  LIBNSPRDLL_NAMES = $(addsuffix .dll, $(addprefix $(NSPR_LIBPATH)/, \
	$(addprefix lib, $(NSPR_LIBNAMES))))
else
  NSPR_SOLIBS = $(addsuffix .$(DLL_SUFFIX),  $(addprefix $(LIB_PREFIX), $(NSPR_LIBNAMES)))
  NSPROBJNAME = $(addsuffix .a, $(addprefix $(LIB_PREFIX), $(NSPR_LIBNAMES)))
  LIBNSPR = $(addprefix $(NSPR_LIBPATH)/, $(NSPR_SOLIBS))
  NSPRLINK = -L$(NSPR_LIBPATH) $(addprefix -l, $(NSPR_LIBNAMES))
endif

### SECURITY #############################
ifdef NSS_INCLUDE_DIR
 SECURITY_INCDIR = $(NSS_INCLUDE_DIR)
else
 ifdef SECURITY_SOURCE_ROOT
  SECURITY_INCDIR = $(SECURITY_SOURCE_ROOT)/dist/public/nss
 else
  SECURITY_INCDIR = $(SECURITY_BUILD_DIR)/include
 endif
endif

ifdef NSS_LIB_DIR
 SECURITY_LIBPATH = $(NSS_LIB_DIR)
else
 ifdef SECURITY_SOURCE_ROOT
  SECURITY_LIBPATH = $(SECURITY_SOURCE_ROOT)/dist/$(MOZ_OBJDIR_NAME)/lib
 else
  SECURITY_LIBPATH = $(SECURITY_BUILD_DIR)/lib
 endif
endif

SECURITY_INCLUDE = -I$(SECURITY_INCDIR)
# add crlutil and ocspclnt when we support CRL and OCSP cert checking in DS
SECURITY_LIBNAMES = ssl3 nss3 softokn3

ifeq ($(ARCH), WINNT)
  SECURITYOBJNAME = $(addsuffix .$(LIB_SUFFIX), $(SECURITY_LIBNAMES))
  LIBSECURITY = $(addprefix $(SECURITY_LIBPATH)/, $(SECURITYOBJNAME))
  SECURITYLINK = /LIBPATH:$(SECURITY_LIBPATH) $(SECURITYOBJNAME)
else
  SECURITYOBJNAME = $(addsuffix .$(DLL_SUFFIX), $(addprefix $(LIB_PREFIX), $(SECURITY_LIBNAMES)))
  LIBSECURITY = $(addprefix $(SECURITY_LIBPATH)/, $(SECURITYOBJNAME))
  SECURITYLINK = -L$(SECURITY_LIBPATH) $(addprefix -l, $(SECURITY_LIBNAMES))
endif

### SECURITY END #############################

####################################################
# LDAP SDK
###################################################

ifdef LDAPCSDK_INCLUDE_DIR
 LDAPSDK_INCDIR = $(LDAPCSDK_INCLUDE_DIR)
else
 ifdef LDAPSDK_SOURCE_ROOT
  LDAPSDK_INCDIR = $(LDAPSDK_SOURCE_ROOT)/dist/public/ldap
 else
  LDAPSDK_INCDIR = $(LDAP_ROOT)/include
 endif
endif

ifdef LDAPCSDK_LIB_DIR
 LDAPSDK_LIBPATH = $(LDAPCSDK_LIB_DIR)
else
 ifdef LDAPSDK_SOURCE_ROOT
  LDAPSDK_LIBPATH = $(LDAPSDK_SOURCE_ROOT)/dist/lib
 else
  LDAPSDK_LIBPATH = $(LDAP_ROOT)/lib
 endif
endif

LDAPSDK_INCLUDE = -I$(LDAPSDK_INCDIR)

# package the include files - needed for the plugin API
LDAPSDK_INCLUDE_FILES = $(wildcard $(LDAPSDK_INCDIR)/*.h)

ifeq ($(ARCH), WINNT)
  LDAP_LIBNAMES = ldapssl32v$(LDAP_SUF) ldap32v$(LDAP_SUF) ldappr32v$(LDAP_SUF)
  LDAPDLL_NAME = $(addprefix ns, $(LDAP_LIBNAMES))
  LDAPOBJNAME = $(addsuffix .$(LIB_SUFFIX), $(LDAPDLL_NAME))
  LDAPLINK = /LIBPATH:$(LDAPSDK_LIBPATH) $(LDAPOBJNAME)
  LDAP_NOSSL_LINK = /LIBPATH:$(LDAPSDK_LIBPATH) nsldap32v$(LDAP_SUF).$(LIB_SUFFIX)
  LIBLDAPDLL_NAMES = $(addsuffix .dll, $(addprefix $(LDAP_LIBPATH)/, $(LDAPDLL_NAME)))

else # not WINNT
  LDAP_SOLIB_NAMES = ssldap$(LDAP_SUF)$(LDAP_DLL_PRESUF) ldap$(LDAP_SUF)$(LDAP_DLL_PRESUF) prldap$(LDAP_SUF)$(LDAP_DLL_PRESUF)
  ifndef LDAP_NO_LIBLCACHE
	LDAP_SOLIB_NAMES += lcache30$(LDAP_DLL_PRESUF)
  endif
  LDAP_DOTALIB_NAMES =
  LDAP_LIBNAMES = $(LDAP_DOTALIB_NAMES) $(LDAP_SOLIB_NAMES)
  LDAP_SOLIBS = $(addsuffix .$(LDAP_DLL_SUFFIX), $(addprefix $(LIB_PREFIX), $(LDAP_SOLIB_NAMES)))
  LDAPOBJNAME = $(addsuffix .$(LIB_SUFFIX), $(addprefix $(LIB_PREFIX), $(LDAP_DOTALIB_NAMES))) \
		$(LDAP_SOLIBS)
  LDAPLINK = -L$(LDAPSDK_LIBPATH) $(addprefix -l,$(LDAP_SOLIB_NAMES))
  LDAP_NOSSL_LINK = -L$(LDAPSDK_LIBPATH) -lldap$(LDAP_SUF)$(LDAP_DLL_PRESUF)

endif

LDAP_LIBPATH = $(LDAPSDK_LIBPATH)
LDAP_INCLUDE = $(LDAPSDK_INCDIR)

### ICU package ##########################################

ICU_LIB_VERSION = 34
ifdef ICU_BIN_DIR
 ICU_BINPATH = $(ICU_BIN_DIR)
else
 ifdef ICU_SOURCE_ROOT
  ICU_BINPATH = $(ICU_SOURCE_ROOT)/built/bin
 else
  ICU_BINPATH = $(ICU_BUILD_DIR)/bin
 endif
endif

ifdef ICU_INCLUDE_DIR
 ICU_INCPATH = $(ICU_INCLUDE_DIR)
else
 ifdef ICU_SOURCE_ROOT
  ICU_INCPATH = $(ICU_SOURCE_ROOT)/built/include
 else
  ICU_INCPATH = $(ICU_BUILD_DIR)/include
 endif
endif

ifdef ICU_LIB_DIR
 ICU_LIBPATH = $(ICU_LIB_DIR)
else
 ifdef ICU_SOURCE_ROOT
  ICU_LIBPATH = $(ICU_SOURCE_ROOT)/built/lib
 else
  ICU_LIBPATH = $(ICU_BUILD_DIR)/lib
 endif
endif

ICU_INCLUDE = -I$(ICU_INCPATH)
ifeq ($(ARCH), WINNT)
  ifeq ($(BUILD_DEBUG), optimize)
    ICU_LIB_SUF=
  else
    ICU_LIB_SUF=d
  endif
  ICU_LIBNAMES = icuin$(ICU_LIB_SUF) icuuc$(ICU_LIB_SUF) icudata
  ICU_DLLNAMES = icuin$(ICU_LIB_VERSION)$(ICU_LIB_SUF) icuuc$(ICU_LIB_VERSION)$(ICU_LIB_SUF) icudt$(ICU_LIB_VERSION)l
  ICULINK = /LIBPATH:$(ICU_LIBPATH) $(addsuffix .$(LIB_SUFFIX),$(ICU_LIBNAMES))
else
  ICU_LIBNAMES = icui18n icuuc icudata
  ICULINK = -L$(ICU_LIBPATH) $(addprefix -l, $(ICU_LIBNAMES))
endif

# Resource Bundle Compiler
ifeq ($(ARCH), WINNT)
    ICU_GENRB = $(ICU_BINPATH)/genrb.exe
else
  ifdef ICU_BIN_DIR
    ICU_GENRB = genrb
  else
    ICU_GENRB = sh ./genrb_wrapper.sh  $(ICU_BUILD_DIR)
  endif
endif

###########################################################

ifeq ($(INTERNAL_BUILD), 1)
include $(ABS_ROOT)/internal_comp_deps.mk
endif
